Index: vorbis-tools/libao/ao_alsa.c
===================================================================
RCS file: /usr/local/cvsroot/vorbis/vorbis-tools/libao/ao_alsa.c,v
retrieving revision 1.1
diff -u -r1.1 ao_alsa.c
--- vorbis-tools/libao/ao_alsa.c	2000/07/22 01:57:05	1.1
+++ vorbis-tools/libao/ao_alsa.c	2000/08/07 22:08:28
@@ -38,7 +38,7 @@
 typedef struct ao_alsa_internal_s
 {
 	snd_pcm_t *pcm_handle;
-	void *buf;
+	char *buf;
 	int buf_size;
 	int buf_end;
 	int card;
@@ -91,7 +91,8 @@
 	{
 	case 8  : param.format.format = SND_PCM_SFMT_S8;
 		  break;
-	case 16 : param.format.format = SND_PCM_SFMT_S16_LE;
+	case 16 : param.format.format = ao_is_big_endian() ?
+		    SND_PCM_SFMT_S16_BE : SND_PCM_SFMT_S16_LE;
 		  break;
 	default : return NULL;
 	}
@@ -191,9 +192,9 @@
 ao_alsa_play (ao_internal_t *state, void* output_samples, uint_32 num_bytes)
 {
 	ao_alsa_internal_t *s = (ao_alsa_internal_t *) state;
-	snd_pcm_t *pcm_handle = s->pcm_handle;
 	int packed = 0;
 	int copy_len;
+	char *samples = (char *) output_samples;
 
 	while (packed < num_bytes)
 	{
@@ -204,7 +205,7 @@
 			copy_len = s->buf_size-s->buf_end;
 
 		memcpy(s->buf + s->buf_end, 
-		       output_samples + packed,
+		       samples + packed,
 		       copy_len); 
 		packed += copy_len;
 		s->buf_end += copy_len;
Index: vorbis-tools/libao/ao_null.c
===================================================================
RCS file: /usr/local/cvsroot/vorbis/vorbis-tools/libao/ao_null.c,v
retrieving revision 1.1
diff -u -r1.1 ao_null.c
--- vorbis-tools/libao/ao_null.c	2000/07/22 01:57:05	1.1
+++ vorbis-tools/libao/ao_null.c	2000/08/07 22:08:28
@@ -59,7 +59,7 @@
 static void
 ao_null_close (ao_internal_t *state)
 {
-	fprintf(stderr, "ao_null: %d bytes sent to null device.\n",
+	fprintf(stderr, "ao_null: %ld bytes sent to null device.\n",
 		((ao_null_internal_t *) state)->byte_counter);
 }
 
Index: vorbis-tools/libao/ao_oss.c
===================================================================
RCS file: /usr/local/cvsroot/vorbis/vorbis-tools/libao/ao_oss.c,v
retrieving revision 1.1
diff -u -r1.1 ao_oss.c
--- vorbis-tools/libao/ao_oss.c	2000/07/22 01:57:05	1.1
+++ vorbis-tools/libao/ao_oss.c	2000/08/07 22:08:28
@@ -120,7 +120,7 @@
 	{
 	case 8: tmp = AFMT_S8;
 		break;
-	case 16: tmp = AFMT_S16_LE;
+	case 16: tmp = ao_is_big_endian() ? AFMT_S16_BE : AFMT_S16_LE;
 		break;
 	default:fprintf(stderr,"libao - Unsupported number of bits: %d.",
 			bits);
Index: vorbis-tools/libao/audio_out.c
===================================================================
RCS file: /usr/local/cvsroot/vorbis/vorbis-tools/libao/audio_out.c,v
retrieving revision 1.1
diff -u -r1.1 audio_out.c
--- vorbis-tools/libao/audio_out.c	2000/07/22 01:57:05	1.1
+++ vorbis-tools/libao/audio_out.c	2000/08/07 22:08:28
@@ -27,6 +27,7 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#include <assert.h>
 #include "audio_out.h"
 
 /* --- Function Tables --- */
@@ -109,10 +110,6 @@
 
 
 
-/* --- Device Table --- */
-
-
-
 /* --- Driver Functions --- */
 
 /* This should have been set by the Makefile */
@@ -169,7 +166,6 @@
 	ao_functions_t *funcs;
 	ao_internal_t *state;
 	ao_device_t *device;
-	int dev_id;
 
 	if (ao_check_driver_id(driver_id))
 	{
@@ -209,24 +205,19 @@
 	char *copy;
 	char *value_ptr;
 	char *colon;
-	ao_option_t *op;
-	int fail = 0;
+	ao_option_t *op = NULL;
 
 	copy = strdup(op_str);
 
 	colon = strchr(copy, ':');
-	if (colon == NULL)
-		fail = 1;
-	else
+	if (colon != NULL) 
 	{
 		value_ptr = colon + 1;
 		*colon = 0x00; // Null terminate the key part
 		
 		// Allocate the option structure
 		op = malloc(sizeof(ao_option_t));
-		if (op == NULL)
-			fail = 1;
-		else
+		if (op != NULL)
 		{
 			op->key = strdup(copy);
 			op->value = strdup(value_ptr);
@@ -235,11 +226,7 @@
 	}
 
 	free(copy);
-
-	if (fail)
-		return NULL;
-	else
-		return op;
+	return op;
 }
 
 
@@ -281,4 +268,14 @@
 		free(options);
 		options = rest;
 	}
+}
+
+/* Helper function lifted from lib/vorbisfile.c */
+int ao_is_big_endian() {
+  uint_16 pattern = 0xbabe;
+  unsigned char *bytewise = (unsigned char *)&pattern;
+  if (bytewise[0] == 0xba) return 1;
+
+  assert(bytewise[0] == 0xbe);
+  return 0;
 }
Index: vorbis-tools/libao/audio_out.h
===================================================================
RCS file: /usr/local/cvsroot/vorbis/vorbis-tools/libao/audio_out.h,v
retrieving revision 1.1
diff -u -r1.1 audio_out.h
--- vorbis-tools/libao/audio_out.h	2000/07/22 01:57:05	1.1
+++ vorbis-tools/libao/audio_out.h	2000/08/07 22:08:28
@@ -105,3 +105,5 @@
 int ao_append_option (ao_option_t **options, const char* op_str);
 
 void ao_free_options (ao_option_t* options);
+
+int ao_is_big_endian();
